//#############################################################################
//
// FILE:   ArcDetect.h
//
// TITLE:  ArcDetect header file.
//
//#############################################################################
// $TI Release: TIDA-010231 v1.00.00.00 $
// $Release Date: Thu Jan 26 15:58:32 CST 2023 $
// $Copyright:
// Copyright (C) 2023 Texas Instruments Incorporated - http://www.ti.com/
//
// ALL RIGHTS RESERVED
// $
//#############################################################################

#ifndef __ARC__DETECT_H__
#define __ARC__DETECT_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <math.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

//*****************************************************************************
//
//! \addtogroup arclib_api
//! @{
//
//*****************************************************************************


/*=== pubic definitions ===*/

#ifndef  ARC_DETECT_TYPES
#define  ARC_DETECT_TYPES

typedef enum _BOOL{ FALSE = 0, TRUE } BOOL;

#endif //ARC_DETECT_TYPES

//
// For Portability, User Is Recommended To Use Following Data Type Size
// Definitions For 16-bit and 32-Bit Signed/Unsigned Integers:
//
#ifndef DSP28_DATA_TYPES
#define DSP28_DATA_TYPES
typedef int             int16;
typedef long            int32;
typedef unsigned int    Uint16;
typedef unsigned long   Uint32;
typedef float           float32;
typedef long double     float64;
#endif

#define SAMPLING_FREQ   250e3        //Software tone test only C28x Port

typedef struct {
        float32    B ; // Analysis BandWidth
        float32    I ; // Min Frequency
        float32    F ; // Filter Weight
        float32    D ; // Bin Discard Factor
        int16      T ; // Threshold
        int16      C ; // Clipping Level
        float32    ADSampleRate ; // Sampling Rate
} arc_tuningparams_t ;

#define ARC_TUNINGPARAMS_DEFAULTS {60000, 50000, 64, 0, 220, 55, SAMPLING_FREQ}

/*=== public data ===*/

extern arc_tuningparams_t   ArcTuningParams ; // Arc detection tuning structure

/*=== public functions ===*/
void ARC_InitArcDetect ( Uint16 NumStrings ) ;
void ARC_DoArcDetect (Uint16 ActiveString) ;

//extern long AD_result[1500];

//*****************************************************************************
//
// Close the Doxygen group.
//! @}
//
//*****************************************************************************

#ifdef __cplusplus
}
#endif /* extern "C" */

#endif   // __ARC__DETECT_H__

//*****************************************************************************
//
// End of File
//
//*****************************************************************************
