//#############################################################################
//
// FILE:  TIDA-010231_hal.c
//
// TITLE: solution hardware abstraction layer,
//        This file consists of common variables and functions
//        for a particular hardware board, like functions to setup the
//        basic peripherals of the board
//
//#############################################################################
// $TI Release: TIDA-010231 v1.00.00.00 $
// $Release Date: Thu Jan 26 15:58:32 CST 2023 $
// $Copyright:
// Copyright (C) 2023 Texas Instruments Incorporated - http://www.ti.com/
//
// ALL RIGHTS RESERVED
// $
//#############################################################################

#include "TIDA-010231_hal.h"

//
//  This routine sets up the basic device configuration such as initializing PLL
//  CPU timers and copying code from FLASH to RAM
//
void ARC_HAL_setupDevice(void)
{
    //
    // Initialize device clock and peripherals
    //
    Device_init();

    //
    // Disable pin locks and enable internal pull-ups.
    //
    Device_initGPIO();

    //
    // Initialize PIE and clear PIE registers. Disables CPU interrupts.
    //

   /// SCI_port_init(0);
    DINT;   
    Interrupt_initModule();

    //
    // Initialize the PIE vector table with pointers to the shell Interrupt
    // Service Routines (ISR).
    //
    Interrupt_initVectorTable();
    IER = 0x0000;   
    IFR = 0x0000;   
}

void ARC_HAL_setupFilterEnablePins(void)
{
    GPIO_setMasterCore(ARC_FILT1_EN, GPIO_CORE_CPU1);
    GPIO_setPinConfig(ARC_FILT1_EN_PIN_CONFIG);
    GPIO_setPadConfig(ARC_FILT1_EN, GPIO_PIN_TYPE_STD);
    GPIO_setDirectionMode(ARC_FILT1_EN, GPIO_DIR_MODE_OUT);
    GPIO_writePin(ARC_FILT1_EN, 1);

    GPIO_setMasterCore(ARC_FILT2_EN, GPIO_CORE_CPU1);
    GPIO_setPinConfig(ARC_FILT2_EN_PIN_CONFIG);
    GPIO_setPadConfig(ARC_FILT2_EN, GPIO_PIN_TYPE_STD);
    GPIO_setDirectionMode(ARC_FILT2_EN, GPIO_DIR_MODE_OUT);
    GPIO_writePin(ARC_FILT2_EN, 1);

    GPIO_setMasterCore(ARC_FILT3_EN, GPIO_CORE_CPU1);
    GPIO_setPinConfig(ARC_FILT3_EN_PIN_CONFIG);
    GPIO_setPadConfig(ARC_FILT3_EN, GPIO_PIN_TYPE_STD);
    GPIO_setDirectionMode(ARC_FILT3_EN, GPIO_DIR_MODE_OUT);
    GPIO_writePin(ARC_FILT3_EN, 1);

    GPIO_setMasterCore(ARC_FILT4_EN, GPIO_CORE_CPU1);
    GPIO_setPinConfig(ARC_FILT4_EN_PIN_CONFIG);
    GPIO_setPadConfig(ARC_FILT4_EN, GPIO_PIN_TYPE_STD);
    GPIO_setDirectionMode(ARC_FILT4_EN, GPIO_DIR_MODE_OUT);
    GPIO_writePin(ARC_FILT4_EN, 1);


}

void ARC_HAL_setupLevelTranslation(void)
{
    GPIO_setMasterCore(ARC_LEVEL_TRANSLATION_EN, GPIO_CORE_CPU1);
    GPIO_setPinConfig(ARC_LEVEL_TRANSLATION_EN_PIN_CONFIG);
    GPIO_setPadConfig(ARC_LEVEL_TRANSLATION_EN, GPIO_PIN_TYPE_STD);
    GPIO_setDirectionMode(32, GPIO_DIR_MODE_OUT);
    GPIO_writePin(ARC_LEVEL_TRANSLATION_EN, 1);
}

void ARC_HAL_setupLEDPins(void)
{
    GPIO_setMasterCore(ARC_LED1, GPIO_CORE_CPU1);
    GPIO_setPinConfig(ARC_LED1_PIN_CONFIG);
    GPIO_setPadConfig(ARC_LED1, GPIO_PIN_TYPE_STD);
    GPIO_setDirectionMode(ARC_LED1, GPIO_DIR_MODE_OUT);

    GPIO_setMasterCore(ARC_LED2, GPIO_CORE_CPU1);
    GPIO_setPinConfig(ARC_LED2_PIN_CONFIG);
    GPIO_setPadConfig(ARC_LED2, GPIO_PIN_TYPE_STD);
    GPIO_setDirectionMode(ARC_LED2, GPIO_DIR_MODE_OUT);

    GPIO_setMasterCore(ARC_LED3, GPIO_CORE_CPU1);
    GPIO_setPinConfig(ARC_LED3_PIN_CONFIG);
    GPIO_setPadConfig(ARC_LED3, GPIO_PIN_TYPE_STD);
    GPIO_setDirectionMode(ARC_LED3, GPIO_DIR_MODE_OUT);

    GPIO_setMasterCore(ARC_LED4, GPIO_CORE_CPU1);
    GPIO_setPinConfig(ARC_LED4_PIN_CONFIG);
    GPIO_setPadConfig(ARC_LED4, GPIO_PIN_TYPE_STD);
    GPIO_setDirectionMode(ARC_LED4, GPIO_DIR_MODE_OUT);


    GPIO_setMasterCore(DEVICE_GPIO_PIN_LED1, GPIO_CORE_CPU1);       
    GPIO_setPinConfig(DEVICE_GPIO_CFG_LED1);                        
    GPIO_setPadConfig(DEVICE_GPIO_PIN_LED1, GPIO_PIN_TYPE_STD);     
    GPIO_setDirectionMode(DEVICE_GPIO_PIN_LED1, GPIO_DIR_MODE_OUT); 

   
     
}

/*
 * configureEPWM - Set up the ePWM2 module with a period
 * of 4 us with a 50% duty. 1/4us = 250kHz for 250 ksps
 * sampling frequency
 * ADC will be triggered every rising edge
 */
void ARC_HAL_setEPWM(void)
{

    //
    //Disable ADC Trigger first, will be enabled later in main
    //
    EPWM_disableADCTrigger(ARC_EPWM_BASE, EPWM_SOC_A);

    //
    //Reset counter register
    //

    HWREGH(ARC_EPWM_BASE + EPWM_O_TBCTL) = 0x0000U;

    //
    //Bring EPM in Up mode
    //

    EPWM_setTimeBaseCounterMode(ARC_EPWM_BASE, EPWM_COUNTER_MODE_UP);

    //
    // Make the timer count up with a period of 4us
    //
    EPWM_setTimeBasePeriod(ARC_EPWM_BASE, 399);

    //
    // Set CMPA to 2us to get a 50% duty
    //
    EPWM_setCounterCompareValue(ARC_EPWM_BASE, EPWM_COUNTER_COMPARE_A, 200U);

    //
    // Set the local ePWM module clock divider to 1
    //
    EPWM_setClockPrescaler(ARC_EPWM_BASE, EPWM_CLOCK_DIVIDER_1,
                           EPWM_HSCLOCK_DIVIDER_1);

    //
    // Start ADC when timer equals zero (note: don't enable yet)
    //
    EPWM_setADCTriggerSource(ARC_EPWM_BASE, EPWM_SOC_A, EPWM_SOC_TBCTR_U_CMPA);
    EPWM_setADCTriggerEventPrescale(ARC_EPWM_BASE, EPWM_SOC_A, 1U);

    //
    // Enable initialization of the SOCA event counter. Since we are
    // disabling the ETSEL.SOCAEN bit, we need a way to reset the SOCACNT.
    // Hence, enable the counter initialize control.
    //
    EPWM_enableADCTriggerEventCountInit(ARC_EPWM_BASE, EPWM_SOC_A);

    EPWM_forceADCTriggerEventCountInit(ARC_EPWM_BASE, EPWM_SOC_A); // EPWM2 SOCA
    EPWM_clearADCTriggerFlag(ARC_EPWM_BASE, EPWM_SOC_A);    // EPWM2 SOCA

    EPWM_enableADCTrigger(EPWM2_BASE, EPWM_SOC_A);
}
void ARC_HAL_setupIntADC(void)
{
    //
    // asysctl initialization
    // Disables the temperature sensor output to the ADC.
    //
    ASysCtl_disableTemperatureSensor();

    //
    // Set the analog voltage reference selection to internal.
    //
    ASysCtl_setAnalogReferenceInternal( ASYSCTL_VREFHIA |
                                        ASYSCTL_VREFHIB |
                                        ASYSCTL_VREFHIC );

    //
    // Set the internal analog voltage reference selection to 1.65V.
    //
    ASysCtl_setAnalogReference1P65( ASYSCTL_VREFHIA |
                                    ASYSCTL_VREFHIB |
                                    ASYSCTL_VREFHIC );
    //
    //ADCA6 initialization
    //
    // ADC Initialization: Write ADC configurations and power up the ADC
    // Configures the ADC module's offset trim
    //
    ADC_setOffsetTrimAll(ADC_REFERENCE_INTERNAL, ADC_REFERENCE_3_3V);

    //
    // Configures the analog-to-digital converter module prescaler.
    //
    ADC_setPrescaler(ARC_ADC_BASE, ADC_CLK_DIV_2_0);

    //
    // Sets the timing of the end-of-conversion pulse
    //
    ADC_setInterruptPulseMode(ARC_ADC_BASE, ADC_PULSE_END_OF_CONV);

    //
    // Powers up the analog-to-digital converter core.
    //
    ADC_enableConverter(ARC_ADC_BASE);

    //
    // Delay for 1ms to allow ADC time to power up
    //
    DEVICE_DELAY_US(5000);

    //
    // SOC Configuration: Setup ADC EPWM channel and trigger settings
    // Disables SOC burst mode.
    //
    ADC_disableBurstMode(ARC_ADC_BASE);

    //
    // Sets the priority mode of the SOCs.
    //
    ADC_setSOCPriority(ARC_ADC_BASE, ADC_PRI_ALL_ROUND_ROBIN);

    //
    // Start of Conversion 0 Configuration
    // Configures a start-of-conversion (SOC) in the ADC and its
    // interrupt SOC trigger.
    //      SOC number      : 0
    //      Trigger         : ARC_ADC_TRIG_SOURCE
    //      Channel         : ARC_ADC_PIN
    //      Sample Window   : ARC_ADC_ACQ_SYS_CLKS
    //      Interrupt Trigger: ADC_INT_SOC_TRIGGER_NONE
    //
    ADC_setupSOC(ARC_ADC_BASE, ARC_ADC_SOC,
                 ARC_ADC_TRIG_SOURCE, ARC_ADC_PIN, ARC_ADC_ACQ_SYS_CLKS);
    ADC_setInterruptSOCTrigger(ARC_ADC_BASE, ARC_ADC_SOC,
                               ADC_INT_SOC_TRIGGER_NONE);

    //
    // ADC Interrupt 1 Configuration
    //      SOC/EOC number  : 0
    //      Interrupt Source: enabled
    //      Continuous Mode : enabled
    //
    ADC_setInterruptSource(ARC_ADC_BASE, ARC_ADC_INT1, ARC_ADC_SOC);
    ADC_enableInterrupt(ARC_ADC_BASE, ARC_ADC_INT1);
    ADC_clearInterruptStatus(ARC_ADC_BASE, ARC_ADC_INT1);
    ADC_enableContinuousMode(ARC_ADC_BASE, ARC_ADC_INT1);

    //
    // ADC Interrupt 2 Configuration
    //      SOC/EOC number  : 0
    //      Interrupt Source: enabled
    //      Continuous Mode : enabled
    //
    ADC_setInterruptSource(ARC_ADC_BASE, ARC_ADC_INT2, ARC_ADC_SOC);
    ADC_enableInterrupt(ARC_ADC_BASE, ARC_ADC_INT2);
    ADC_clearInterruptStatus(ARC_ADC_BASE, ARC_ADC_INT2);
    ADC_enableContinuousMode(ARC_ADC_BASE, ARC_ADC_INT2);

    //
    //Clear interrupt flag
    //
    HWREGH(ARC_ADC_BASE + ADC_O_INTFLGCLR) = 0x3U; // ADCA
}
/*
 * configureDMA - Configures DMA Channel 1, 2 and 3 to copy data from ADCResult
 * register to intermediate buffers ADCResult1 and ADCResult2 and then into
 * CH1Data
 * CH1 Copies first 512 Samples from ADCResult register to ADCResults1 Buffer
 * CH2 Copies second 512 Samples from ADCResult register to ADCResults2 Buffer
 * CH1 and CH2 are triggered by ADC_Interrupts after every conversion
 * CH3 Copies data from ADC_ResultsN Buffer to CH1Data while the other
 * ADCResults buffer is filled
 * CH3 is triggered once by SW and copies 512 Samples
 */
void ARC_HAL_setupDMA(void)
{
    //
    // Perform a hard reset on DMA
    //
    DMA_initController();
    //
    // Allow DMA to run free on emulation suspend
    //
    DMA_setEmulationMode(DMA_EMULATION_FREE_RUN);

    //
    // DMA channel 1 set up for ADCA first 512 Samples
    //
    DMA_configAddresses(ARC_DMA1_BASE, &ARC_ADCResults1,
                        (uint16_t *)ARC_ADC_RESULTS_BASE);

    //
    //Transfer 1 Word (16-Bit) per burst
    //
    DMA_configBurst(ARC_DMA1_BASE, 1, 0, 1);
    //
    //Do SAMPLES amount of burst per transfer
    //
    DMA_configTransfer(ARC_DMA1_BASE, ARC_SAMPLES / 2, 0, 1);
    DMA_configMode(ARC_DMA1_BASE, DMA_TRIGGER_ADCA1,
                   (DMA_CFG_ONESHOT_DISABLE | DMA_CFG_CONTINUOUS_DISABLE |
                           DMA_CFG_SIZE_16BIT));

    DMA_enableTrigger(ARC_DMA1_BASE);
    DMA_disableOverrunInterrupt(ARC_DMA1_BASE);
    DMA_setInterruptMode(ARC_DMA1_BASE, DMA_INT_AT_END);
    DMA_enableInterrupt(ARC_DMA1_BASE);

    //
    // DMA channel 2 set up for ADCA second 512 Samples
    //
    DMA_configAddresses(ARC_DMA2_BASE, &ARC_ADCResults2,
                        (uint16_t *)ARC_ADC_RESULTS_BASE);

    //
    //Transfer 1 Word (16-Bit) per burst
    //
    DMA_configBurst(ARC_DMA2_BASE, 1, 0, 1);
    //
    //Do SAMPLES amount of burst per transfer
    //
    DMA_configTransfer(ARC_DMA2_BASE, ARC_SAMPLES / 2, 0, 1);
    DMA_configMode(ARC_DMA2_BASE, DMA_TRIGGER_ADCA2,
                   (DMA_CFG_ONESHOT_DISABLE | DMA_CFG_CONTINUOUS_DISABLE |
                           DMA_CFG_SIZE_16BIT));

    DMA_enableTrigger(ARC_DMA2_BASE);
    DMA_disableOverrunInterrupt(ARC_DMA2_BASE);
    DMA_setInterruptMode(ARC_DMA2_BASE, DMA_INT_AT_END);
    DMA_enableInterrupt(ARC_DMA2_BASE);

    //
    // DMA channel 3 set up for copying from ADCResult1 or ADCResults to CH1Data
    //
    DMA_configAddresses(ARC_DMA3_BASE, &ARC_CH1Data,
                        &ARC_ADCResults1);

    //
    //Transfer 1 Word (16-Bit) per burst
    //
    DMA_configBurst(ARC_DMA3_BASE, 1, 1, 1);
    //
    //Do SAMPLES amount of burst per transfer
    //
    DMA_configTransfer(ARC_DMA3_BASE, ARC_SAMPLES / 2, 1, 1);
    DMA_configMode(ARC_DMA3_BASE, DMA_TRIGGER_SOFTWARE,
                   (DMA_CFG_ONESHOT_ENABLE | DMA_CFG_CONTINUOUS_DISABLE |
                           DMA_CFG_SIZE_16BIT));

    DMA_enableTrigger(ARC_DMA3_BASE);
    DMA_disableOverrunInterrupt(ARC_DMA3_BASE);
    DMA_setInterruptMode(ARC_DMA3_BASE, DMA_INT_AT_END);
    DMA_enableInterrupt(ARC_DMA3_BASE);

    DMA_clearTriggerFlag(ARC_DMA1_BASE);   // DMA channel 1
    DMA_clearTriggerFlag(ARC_DMA2_BASE);   // DMA channel 2
    DMA_clearTriggerFlag(ARC_DMA3_BASE);   // DMA channel 3

    //
    // Start DMA 1
    //
    DMA_startChannel(ARC_DMA1_BASE);

}
void ARC_HAL_setupDAC(void){
    //
    // Set VDAC as the DAC reference voltage.
    // Use Internal 1.65V Reference
    //
    ASysCtl_setAnalogReferenceInternal(ASYSCTL_VREFHIA);
    ASysCtl_setAnalogReference2P5(ASYSCTL_VREFHIA);

    DAC_setReferenceVoltage(ARC_DAC1_BASE, DAC_REF_ADC_VREFHI);

    //
    //Set gain to 2 to get full output of 3.3V
    //
    DAC_setGainMode(ARC_DAC1_BASE, DAC_GAIN_ONE);

    //
    // Enable the DAC output
    //
    DAC_enableOutput(ARC_DAC1_BASE);

    //
    // Set the DAC shadow output to 0
    //
    DAC_setShadowValue(ARC_DAC1_BASE, 0);
    //
    // Delay for buffered DAC to power up
    //
    DEVICE_DELAY_US(10);

    //
    // Set VDAC as the DAC reference voltage.
    // Use Internal 1.65V Reference
    //
    ASysCtl_setAnalogReferenceInternal(ASYSCTL_VREFHIA);
    ASysCtl_setAnalogReference2P5(ASYSCTL_VREFHIA);

    DAC_setReferenceVoltage(ARC_DAC1_BASE, DAC_REF_ADC_VREFHI);

    //
    //Set gain to 2 to get full output of 3.3V
    //
    DAC_setGainMode(ARC_DAC1_BASE, DAC_GAIN_ONE);

    //
    // Enable the DAC output
    //
    DAC_enableOutput(ARC_DAC1_BASE);

    //
    // Set the DAC shadow output to 0
    //
    DAC_setShadowValue(ARC_DAC1_BASE, 0);
    //
    // Delay for buffered DAC to power up
    //
    DEVICE_DELAY_US(10);
}

void ARC_HAL_writeStatusLED(uint32_t Led, uint32_t status){
    GPIO_writePin(Led, status);
}

void ARC_HAL_disablePWMClk(void)
{
    //
    // Stop the ePWM clock
    //
    SysCtl_disablePeripheral(SYSCTL_PERIPH_CLK_TBCLKSYNC);
}

void ARC_HAL_enablePWMClk(void)
{
    //
    // Start the ePWM clock
    //
    SysCtl_enablePeripheral(SYSCTL_PERIPH_CLK_TBCLKSYNC);
}

void ARC_HAL_setupInterrupt(void)
{
    //
    // Set up ISR for DMA ch1 - occurs when DMA transfer is complete
    //
    Interrupt_register(ARC_DMA1_INT, &ARC_DMA1_ISR);
    Interrupt_register(ARC_DMA2_INT, &ARC_DMA2_ISR);
    Interrupt_register(ARC_DMA3_INT, &ARC_DMA3_ISR);

    //
    // Enable DMA interrupt - Group 7, interrupt 1
    //
    Interrupt_enable(ARC_DMA1_INT);
    Interrupt_enable(ARC_DMA2_INT);
    Interrupt_enable(ARC_DMA3_INT);

    //
    // Enable Global Interrupt (INTM) and real-time interrupt (DBGM)
    //
  //  EINT;
  //  ERTM;
}
void ARC_HAL_disableADCTrigger(void){
    EPWM_disableADCTrigger(ARC_EPWM_BASE, EPWM_SOC_A);
}
void ARC_HAL_enableADCTrigger(void){
    EPWM_enableADCTrigger(ARC_EPWM_BASE, EPWM_SOC_A);
}
void ARC_HAL_DMA_stop(uint32_t base){
    DMA_stopChannel(base);
}

void ARC_HAL_DMA_start(uint32_t base){
    DMA_startChannel(base);
}
void ARC_HAL_DMA_startAndTrigger(uint32_t base){
    DMA_startChannel(base);
    DMA_forceTrigger(base);
}
void ARC_HAL_DMA_configAddresses(uint32_t base, const void *dest,
                                 const void * source){
    DMA_configAddresses(base, dest, source);
}
void ARC_HAL_DMA_clearInterruptFlag(void){
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP7);
}
