//#############################################################################
//
// FILE:   TIDA-010231_hal.h
//
// TITLE: solution hardware abstraction layer header file
//        This file consists of common variables and functions
//        for a particular hardware board, like functions to setup the
//        basic peripherals of the board
//
//#############################################################################
// $TI Release: TIDA-010231 v1.00.00.00 $
// $Release Date: Thu Jan 26 15:58:32 CST 2023 $
// $Copyright:
// Copyright (C) 2023 Texas Instruments Incorporated - http://www.ti.com/
//
// ALL RIGHTS RESERVED
// $
//#############################################################################

#ifndef TIDA_010231_HAL_H_
#define TIDA_010231_HAL_H_

#include "driverlib.h"
#include "device.h"
#include "TIDA-010231_settings.h"

//
// Function Prototypes
//
void ARC_HAL_setupDevice(void);
void ARC_HAL_setupFilterEnablePins(void);
void ARC_HAL_setupLEDPins(void);
void ARC_HAL_setEPWM(void);
void ARC_HAL_setupIntADC(void);
void ARC_HAL_setupDMA(void);
void ARC_HAL_setupDAC(void);
void ARC_HAL_writeStatusLED(uint32_t, uint32_t);
void ARC_HAL_setupLevelTranslation(void);
void ARC_HAL_disablePWMClk(void);
void ARC_HAL_enablePWMClk(void);
void ARC_HAL_setupInterrupt(void);
void ARC_HAL_disableADCTrigger(void);
void ARC_HAL_enableADCTrigger(void);
void ARC_HAL_DMA_stop(uint32_t);
void ARC_HAL_DMA_start(uint32_t);
void ARC_HAL_DMA_startAndTrigger(uint32_t);
void ARC_HAL_DMA_configAddresses(uint32_t, const void *, const void *);
void ARC_HAL_DMA_clearInterruptFlag(void);

extern int16_t ARC_CH1Data[ARC_SAMPLES];
extern int16_t ARC_ADCResults1[ARC_SAMPLES / 2];
extern int16_t ARC_ADCResults2[ARC_SAMPLES / 2];

/*
 * Interrupt service routines
 */
__interrupt void ARC_DMA1_ISR(void);
__interrupt void ARC_DMA2_ISR(void);
__interrupt void ARC_DMA3_ISR(void);



#endif /* TIDA_010231_HAL_H_ */
