#include "hw_module.h"
#include "structs.h"      
//*****************************************************************************
//
// Board Configurations
// Initializes the rest of the modules. 
// Call this function in your application if you wish to do all module 
// initialization.
// If you wish to not use some of the initializations, instead of the 
// Board_init use the individual Module_inits
//
//*****************************************************************************

void HW_init()
{
	EALLOW;

	//SCI_port_init();
	LED_init();
	    
	CPUTIMER_init();
    CPUTIMER_Int_init();
  //  SCI_init(0);          

   
	EDIS;
}

//*****************************************************************************
//
// PINMUX Configurations
//
//*****************************************************************************
void SCI_port_init(uint8_t port)
{
    if(port == 0)
    {
    
    	GPIO_setPinConfig(GPIO_28_SCIA_RX);
    	GPIO_setPadConfig(SCIA_SCIRX_GPIO, GPIO_PIN_TYPE_STD); // | GPIO_PIN_TYPE_PULLUP);
    	GPIO_setQualificationMode(SCIA_SCIRX_GPIO, GPIO_QUAL_ASYNC);
        GPIO_setMasterCore(SCIA_SCIRX_GPIO, GPIO_CORE_CPU1);
        GPIO_setDirectionMode(SCIA_SCIRX_GPIO, GPIO_DIR_MODE_IN);

        
    	GPIO_setPinConfig(GPIO_29_SCIA_TX);
    	GPIO_setPadConfig(SCIA_SCITX_GPIO, GPIO_PIN_TYPE_STD);
    	GPIO_setQualificationMode(SCIA_SCITX_GPIO, GPIO_QUAL_ASYNC);
        GPIO_setMasterCore(SCIA_SCITX_GPIO, GPIO_CORE_CPU1);
        GPIO_setDirectionMode(SCIA_SCITX_GPIO, GPIO_DIR_MODE_OUT);
    }
    else if(port == 1)
    {
        GPIO_setPinConfig(GPIO_13_SCIB_RX);
        GPIO_setPadConfig(SCIB_SCIRX_GPIO, GPIO_PIN_TYPE_STD | GPIO_PIN_TYPE_PULLUP);
        GPIO_setQualificationMode(SCIB_SCIRX_GPIO, GPIO_QUAL_ASYNC);
        GPIO_setMasterCore(SCIB_SCIRX_GPIO, GPIO_CORE_CPU1);
        GPIO_setDirectionMode(SCIB_SCIRX_GPIO, GPIO_DIR_MODE_IN);
    
        
        GPIO_setPinConfig(GPIO_12_SCIB_TX);
        GPIO_setPadConfig(SCIB_SCITX_GPIO, GPIO_PIN_TYPE_STD);
        GPIO_setQualificationMode(SCIB_SCITX_GPIO, GPIO_QUAL_ASYNC);
        GPIO_setMasterCore(SCIB_SCITX_GPIO, GPIO_CORE_CPU1);
        GPIO_setDirectionMode(SCIB_SCITX_GPIO, GPIO_DIR_MODE_OUT);

    }

}


//*****************************************************************************
//
// CPUTIMER Configurations
//
//*****************************************************************************
void CPUTIMER_init()
{
	led_work_timer_init();
}

void led_work_timer_init()
{
	CPUTimer_setEmulationMode(this_CPUTIMER0_BASE, CPUTIMER_EMULATIONMODE_STOPAFTERNEXTDECREMENT);
	CPUTimer_setPreScaler(this_CPUTIMER0_BASE, 0);
	CPUTimer_setPeriod(this_CPUTIMER0_BASE, 0x5F5E100);
	CPUTimer_enableInterrupt(this_CPUTIMER0_BASE);
	CPUTimer_stopTimer(this_CPUTIMER0_BASE);

	CPUTimer_reloadTimerCounter(this_CPUTIMER0_BASE);
}

//*****************************************************************************
//
// GPIO Configurations
//
//*****************************************************************************
void LED_init()
{
	LED0_GPIO_init();
}

void LED0_GPIO_init()
{
	GPIO_setPadConfig(LED0_GPIO, GPIO_PIN_TYPE_STD);
	GPIO_setQualificationMode(LED0_GPIO, GPIO_QUAL_SYNC);
	GPIO_setDirectionMode(LED0_GPIO, GPIO_DIR_MODE_OUT);
	GPIO_setMasterCore(LED0_GPIO, GPIO_CORE_CPU1);
}

void LED7_GPIO_init()
{
	GPIO_setPadConfig(LED7_TIDAB_GPIO, GPIO_PIN_TYPE_STD);
	GPIO_setQualificationMode(LED7_TIDAB_GPIO, GPIO_QUAL_SYNC);
	GPIO_setDirectionMode(LED7_TIDAB_GPIO, GPIO_DIR_MODE_OUT);
	GPIO_setMasterCore(LED7_TIDAB_GPIO, GPIO_CORE_CPU1);
}


//*****************************************************************************
//
// INTERRUPT Configurations
//
//*****************************************************************************
void CPUTIMER_Int_init()
{
	
	// Interrupt Setings for INT_myCPUTIMER0
	Interrupt_register(INT_CPUTIMER0, &INT_CPUTIMER0_ISR);
	Interrupt_enable(INT_CPUTIMER0);

}
//*****************************************************************************
//
// SCI Configurations
//
//*****************************************************************************
void SCI_init(uint8_t port)
{
    SCI_port_init(port);
    SCI_Config_init(port);
}

void SCI_Config_init(uint8_t port)
{
    if(port == 0)
    {
        SCI_performSoftwareReset(SCIA_BASE);
    	SCI_setConfig(SCIA_BASE, DEVICE_LSPCLK_FREQ, SCIA_BAUDRATE, (SCI_CONFIG_WLEN_8|SCI_CONFIG_STOP_ONE|SCI_CONFIG_PAR_NONE));
    	SCI_resetChannels(SCIA_BASE);
        SCI_clearInterruptStatus(SCIA_BASE, SCI_INT_TXRDY| SCI_INT_RXRDY_BRKDT);
      	SCI_enableModule(SCIA_BASE);
        SCI_performSoftwareReset(SCIA_BASE);
        

        SCI_enableInterrupt(SCIA_BASE, SCI_INT_RXRDY_BRKDT);
        
    	//SCI_clearOverflowStatus(SCIA_BASE);
    	//SCI_resetTxFIFO(SCIA_BASE);
    	//SCI_resetRxFIFO(SCIA_BASE);


    	//SCI_disableLoopback(SCIA_BASE);
        
        //SCI_disableModule(SCIA_BASE);
    	//SCI_setFIFOInterruptLevel(SCIA_BASE, SCI_FIFO_TX0, SCI_FIFO_TX0);
        //SCI_enableFIFO(SCIA_BASE);

    }
    else if(port == 1)
    {
//    
    SCI_clearInterruptStatus(SCIB_BASE, SCI_INT_RXFF | SCI_INT_TXFF | SCI_INT_FE | SCI_INT_OE | SCI_INT_PE | SCI_INT_RXERR | SCI_INT_RXRDY_BRKDT | SCI_INT_TXRDY);
    
    SCI_clearInterruptStatus(SCIB_BASE, SCI_INT_RXRDY_BRKDT | SCI_INT_TXRDY);
        SCI_clearOverflowStatus(SCIB_BASE);
        SCI_resetTxFIFO(SCIB_BASE);
        SCI_resetRxFIFO(SCIB_BASE);
        SCI_resetChannels(SCIB_BASE);
        SCI_setConfig(SCIB_BASE, DEVICE_LSPCLK_FREQ, SCIA_BAUDRATE, (SCI_CONFIG_WLEN_8|SCI_CONFIG_STOP_ONE|SCI_CONFIG_PAR_NONE));
        SCI_disableLoopback(SCIB_BASE);
        SCI_performSoftwareReset(SCIB_BASE);
        SCI_disableModule(SCIB_BASE);
        SCI_setFIFOInterruptLevel(SCIB_BASE, SCI_FIFO_TX0, SCI_FIFO_RX1);
        SCI_enableFIFO(SCIB_BASE);
        SCI_enableModule(SCIB_BASE);
    }
}



__interrupt void sciaRxISR(void)
{
    
    p_var->m_uart_rx_buffer[p_var->m_uart_rx_count++] =  SCI_readCharBlockingFIFO(SCIA_BASE);

    if(p_var->m_uart_rx_buffer[p_var->m_uart_rx_count - 1] == '\n')
    {
        p_var->m_uart_rx_buffer[p_var->m_uart_rx_count] = '\0';

        p_var->m_uart_rx_count = 0;
        p_var->m_uart_rx_compl_flag = true;


    }
            

    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);
//    SCI_clearInterruptStatus(SCIA_BASE, SCI_INT_RXFF);
    SCI_clearInterruptStatus(SCIA_BASE, SCI_INT_RXRDY_BRKDT);
}




