//#############################################################################
//
// FILE:   empty_driverlib_main.c
//
//! \addtogroup driver_example_list
//! <h1>Empty Project Example</h1> 
//!
//! This example is an empty project setup for Driverlib development.
//!
//
//#############################################################################
//
//
// $Copyright:
// Copyright (C) 2023 Texas Instruments Incorporated - http://www.ti.com/
//
// Redistribution and use in source and binary forms, with or without 
// modification, are permitted provided that the following conditions 
// are met:
// 
//   Redistributions of source code must retain the above copyright 
//   notice, this list of conditions and the following disclaimer.
// 
//   Redistributions in binary form must reproduce the above copyright
//   notice, this list of conditions and the following disclaimer in the 
//   documentation and/or other materials provided with the   
//   distribution.
// 
//   Neither the name of Texas Instruments Incorporated nor the names of
//   its contributors may be used to endorse or promote products derived
//   from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// $
//#############################################################################

//
// Included Files
//
#include "TIDA-010231.h"
#include "driverlib.h"
#include "device.h"
#include "board.h"
#include "c2000ware_libraries.h"
#include "hw_module.h"
#include "utils.h"
#include "structs.h"

#ifdef _FLASH
// These are defined by the linker (see device linker command file)
extern uint16_t RamfuncsLoadStart;
extern uint16_t RamfuncsLoadSize;
extern uint16_t RamfuncsRunStart;
#endif
//
uint16_t cpuTimer0IntCount; //number of times TIMER 0 ISR is triggered
uint16_t delayCount;        //number (0-9) to scale the LED frequency


struct  var_s       var_buf;
struct  var_s       *p_var;



uint16_t counter = 0;
unsigned char *msg;
__interrupt void sciaRxISR(void);

__interrupt void INT_CPUTIMER0_ISR(void);

unsigned int Mem_Rd(int *);

void reg_init(void)
{
    p_var = &var_buf;
    
    p_var->complet_flag             = 0;
    p_var->m_state                  = STATE_IDLE;
    p_var->m_uart_rx_count          = 0;

}

#define AD_RSULT_BASE   LS4_RAM_BASE
// Main
//
void main(void)
{

    //unsigned long result_val;
    /*Basic setup of the device*/
    ARC_HAL_setupDevice();

    ARC_HAL_disablePWMClk();


    /*These enable signals are mandatory on older revisions of TIDA-010231 HW!*/
    ARC_HAL_setupFilterEnablePins();
    ARC_HAL_setupLevelTranslation();

    /*Setups Pins for the 4 Status LED on top of TIDA-010231 HW*/
    ARC_HAL_setupLEDPins();

    /*Turn on all status LEDs */
    ARC_HAL_writeStatusLED(ARC_LED1, 1);
    ARC_HAL_writeStatusLED(ARC_LED2, 1);
    ARC_HAL_writeStatusLED(ARC_LED3, 1);
    ARC_HAL_writeStatusLED(ARC_LED4, 1);

    ARC_HAL_writeStatusLED(DEVICE_GPIO_PIN_LED1,0);   

    /*Setup DAC which can be used for diagnostics*/
    ARC_HAL_setupDAC();

    /*Setup EPM used for regular ADC triggers at 250kHz*/
    ARC_HAL_setEPWM();

    /*Setup DMAs to copy data from ADC results buffer to internal memory*/
    ARC_HAL_setupDMA();

    /*Setup ADC to sample input signal, triggered by EPWM*/
    ARC_HAL_setupIntADC();
  
    /* Initialize Arc Detection functions*/
    ARC_InitArcDetect(1);
    ARC_HAL_setupInterrupt();
    ARC_HAL_enablePWMClk();

    HW_init();               
  
    reg_init();
  
    
    CPUTimer_startTimer(this_CPUTIMER0_BASE);
  

    SCI_port_init(0);
  
        
    SCI_Config_init(0);
  

    Interrupt_register(INT_SCIA_RX, sciaRxISR);
  

    SCI_clearInterruptStatus(SCIA_BASE, SCI_INT_TXRDY | SCI_INT_RXRDY_BRKDT);
  
        
    printfU0("********** Product Information ******************\r\n");
    printfU0("Product Type        new Test proj\r\n");
    printfU0("Model Name          INC-1111\r\n");
    sprintf(p_var->txString, "Release Date        %s , %s\r\n", __DATE__, __TIME__); 
    printfU0(p_var->txString);
    printfU0("Supplier            I&C Technology\r\n");
    printfU0("*************************************************\r\n");

    
    Interrupt_enable(INT_SCIA_RX);
  
   // Interrupt_enable(INT_SCIA_TX);
    Interrupt_clearACKGroup(INTERRUPT_ACK_GROUP9);
  

    //
    // Enable global interrupts.
    //
    EINT;


     while(1)
        {
            if(p_var->m_one_second_flag)
            {
                p_var->m_state = STATE_SECOND;
            }
            else if(p_var->m_uart_rx_compl_flag)
            {
    
                p_var->m_state = STATE_UART_ISR;
            }
            else 
            {
                p_var->m_state = STATE_IDLE;
    
            }
    
            switch(p_var->m_state)
            {
                case STATE_IDLE:
                {

                    if(ARC_ReinitArcDetect == 1)
                    {
                        ARC_reinitArcDetect();
                    }
                    if(ARC_startArcDetect == 1)
                    {
                        ARC_startArcDetect = 0;
                        ARC_Busy = 1;
                        ARC_DoArcDetect(0);
                        ARC_Busy = 0;
                    }
    
                    if(ARC_DataBufferFull)
                    {
                        if(p_var->complet_flag == 0)
                        {
                         
                        }
                        p_var->complet_flag = 1 ;
                                   
                    }
                   
#if 1
                    if(!ARC_DataBufferFull)
                    {
                        if(p_var->complet_flag == 1)
                        {
                            p_var->complet_flag = 0 ;
                        }
                    }
#endif


                    break;
                }
                
                case STATE_SECOND:
                {
                 
                    GPIO_togglePin(DEVICE_GPIO_PIN_LED2);
                    printfU0("One senonc\r\n");
                    one_senond_buf_print();
                    p_var->m_one_second_flag = 0;
                    
                    break;
                }
              
                case STATE_UART_ISR:
                {
                    p_var->m_uart_rx_compl_flag = false;            
                    //at_command();
    
                    break;
                }
    
                default:
                break;
                
            }
        }

   // for(;;)
   // {
   // }
}

__interrupt void ARC_DMA1_ISR(void)
{
    runArcDMA1ISR();
}

__interrupt void ARC_DMA2_ISR(void)
{
    runArcDMA2ISR();
}

__interrupt void ARC_DMA3_ISR(void)
{
    runArcDMA3ISR();
}
__interrupt void INT_CPUTIMER0_ISR(void)

{
    cpuTimer0IntCount++;
    p_var->m_one_second_flag = 1;

    
    //
    // Acknowledge this interrupt to receive more interrupts from group 1
    //
    Interrupt_clearACKGroup(INT_CPUTIMER0_INTERRUPT_ACK_GROUP);
}
// End of File
//
